@@ -9,7 +9,7 @@ $month++;
 my $suffix = sprintf("%04d%02d%02d", $yr19, $month, $day);
 $dest = sprintf("I:/Uv/releases/qgvdial/%04d-%02d-%02d", $yr19, $month, $day);
 if ((!(-e $dest)) or (!(-d $dest))) {
-    $cmd = "mkdir $dest";
+    $cmd = "powershell mkdir $dest";
     print("$cmd\n");
     system($cmd);
 }
@@ -53,7 +53,7 @@ print PRO_FILE "VERSION=__QGVDIAL_VERSION__\n";
 close PRO_FILE;
 
 # Version changes
-$cmd = "cd qgvdial-$qver/src & perl ../build-files/version.pl __QGVDIAL_VERSION__ $qver";
+$cmd = "cd qgvdial-$qver & perl ./build-files/version.pl __QGVDIAL_VERSION__ $qver";
 print("$cmd\n");
 system($cmd);
 
@@ -66,11 +66,16 @@ system($cmd);
 my $enterdir = "cd qgvdial-$qver/src & set BUILDDIR=%CD% & set SOURCEDIR=%CD%";
 
 # qmake, make release-gcce, make installer_sis
-$cmd = "$enterdir & qmake.exe src.pro -r -spec symbian-sbsv2 CONFIG+=release -after OBJECTS_DIR=obj MOC_DIR=moc UI_DIR=ui RCC_DIR=rcc QMLJSDEBUGGER_PATH=%QTSDK_SLASH%/../QtCreator/share/qtcreator/qml/qmljsdebugger & $s_make release-gcce -w & $s_make installer_sis -w";
+$cmd = "$enterdir & qmake.exe src.pro -r -spec symbian-sbsv2 CONFIG+=release -after OBJECTS_DIR=obj MOC_DIR=moc UI_DIR=ui RCC_DIR=rcc QMLJSDEBUGGER_PATH=%QTSDK_SLASH%/../QtCreator/share/qtcreator/qml/qmljsdebugger & $s_make release-gcce -w & $s_make installer_sis -w QT_SIS_CERTIFICATE=%QGV_CERT% QT_SIS_KEY=%QGV_KEY%";
+print("$cmd\n");
+system($cmd);
+
+$cmd = "$enterdir & signsis.exe -u qgvdial.sis unsigned_qgvdial.sis";
 print("$cmd\n");
 system($cmd);
 
 # Copy the sis files to the outer directory
-$cmd = "$enterdir & powershell cp qgvdial.sis $dest/qgvdial_$qver.sis & powershell cp qgvdial_installer.sis $dest/qgvdial_installer_$qver.sis";
+#$cmd = "$enterdir & powershell cp qgvdial.sis $dest/qgvdial_$qver.sis & powershell cp qgvdial_installer.sis $dest/qgvdial_installer_$qver.sis";
+$cmd = "$enterdir & powershell cp qgvdial.sis $dest/qgvdial_$qver.sis & powershell cp unsigned_qgvdial.sis $dest/unsigned_qgvdial_$qver.sis";
 print("$cmd\n");
 system($cmd);
