@@ -45,6 +45,10 @@ myMessageOutput(QtMsgType type, const char *msg)
 int
 main (int argc, char *argv[])
 {
+#if defined(Q_WS_S60)
+    MainApp::setAttribute (Qt::AA_S60DontConstructApplicationPanes);
+#endif
+
     pOldHandler = qInstallMsgHandler(myMessageOutput);
 
     MainApp app(argc, argv);
@@ -70,11 +74,14 @@ main (int argc, char *argv[])
     MainWindow w;
     pw = &w;
     app.setActivationWindow (&w);
-    app.setQuitOnLastWindowClosed (false);
 
-#if defined(Q_WS_S60)
-    w.showMaximized();
-#elif defined(Q_WS_MAEMO_5)
+#if defined(Q_OS_SYMBIAN)
+    app.setQuitOnLastWindowClosed (true);
+#else
+    app.setQuitOnLastWindowClosed (false);
+#endif
+
+#if MOBILE_OS
     w.showFullScreen ();
 #else
     w.show();
